@@ -432,9 +432,18 @@ class _SignedPoster:
         for reqkey in self.required:
             if reqkey not in kwset:
                 raise TypeError("SignedPoster is missing one required named argument '", reqkey, "'")
+        if self.url.endswith("/new-ledger"):
+            if "options" not in kwdict:
+                kwdict["options"] = {}
+            if "root" not in kwdict["options"]:
+                kwdict["options"]["root"] = []
+            if self.signer.auth_id not in kwdict["options"]["root"]:
+                kwdict["options"]["root"].append(self.signer.auth_id)
         body = json.dumps(kwdict, indent=4, sort_keys=True)
         headers = {"Content-Type": "application/json"}
         if not self.unsigned:
+            if self.debug:
+                print("Signing with:", self.signer.auth_id)
             body, headers, _ = self.signer.sign_query(kwdict)
         rval = await self._post_body_with_headers(body, headers)
         # If this is a new-db or new-legger, we need to await till it comes into existance.
@@ -1720,6 +1729,8 @@ class _FlureeDbClient:
                     Return body from server
                 """
                 if self.signer:
+                    if debug:
+                        print("Signing with:", self.signer.auth_id)
                     body, headers, _ = self.signer.sign_query(query_body, querytype=self.api_endpoint)
                 else:
                     body = json.dumps(query_body, indent=4, sort_keys=True)
@@ -1741,6 +1752,8 @@ class _FlureeDbClient:
                     Return body from server
 
                 """
+                if debug:
+                    print("Signing with:", self.signer.auth_id)
                 command = self.signer.sign_transaction(transact_obj, deps)
                 body = json.dumps(command, indent=4, sort_keys=True)
                 headers = {"content-type": "application/json"}
